@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENSET"]
-pub type R = crate::R<u32, super::INTENSET>;
-#[doc = "Writer for register INTENSET"]
-pub type W = crate::W<u32, super::INTENSET>;
-#[doc = "Register INTENSET `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENSET {
-    type Type = u32;
+#[doc = "Register `INTENSET` reader"]
+pub struct R(crate::R<INTENSET_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENSET_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENSET_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENSET_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENSET` writer"]
+pub struct W(crate::W<INTENSET_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENSET_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENSET_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENSET_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[0\\]\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<IN0_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN0`"]
-pub type IN0_R = crate::R<bool, IN0_A>;
+#[doc = "Field `IN0` reader - Write '1' to enable interrupt for event IN\\[0\\]"]
+pub struct IN0_R(crate::FieldReader<bool, IN0_A>);
 impl IN0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN0_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN0_A {
@@ -38,12 +66,19 @@ impl IN0_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN0_A::DISABLED
+        **self == IN0_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN0_A::ENABLED
+        **self == IN0_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN0_R {
+    type Target = crate::FieldReader<bool, IN0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[0\\]\n\nValue on reset: 0"]
@@ -58,7 +93,7 @@ impl From<IN0_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN0`"]
+#[doc = "Field `IN0` writer - Write '1' to enable interrupt for event IN\\[0\\]"]
 pub struct IN0_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +101,7 @@ impl<'a> IN0_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN0_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -88,7 +121,7 @@ impl<'a> IN0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -106,9 +139,13 @@ impl From<IN1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN1`"]
-pub type IN1_R = crate::R<bool, IN1_A>;
+#[doc = "Field `IN1` reader - Write '1' to enable interrupt for event IN\\[1\\]"]
+pub struct IN1_R(crate::FieldReader<bool, IN1_A>);
 impl IN1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN1_A {
@@ -120,12 +157,19 @@ impl IN1_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN1_A::DISABLED
+        **self == IN1_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN1_A::ENABLED
+        **self == IN1_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN1_R {
+    type Target = crate::FieldReader<bool, IN1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[1\\]\n\nValue on reset: 0"]
@@ -140,7 +184,7 @@ impl From<IN1_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN1`"]
+#[doc = "Field `IN1` writer - Write '1' to enable interrupt for event IN\\[1\\]"]
 pub struct IN1_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +192,7 @@ impl<'a> IN1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN1_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -170,7 +212,7 @@ impl<'a> IN1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -188,9 +230,13 @@ impl From<IN2_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN2`"]
-pub type IN2_R = crate::R<bool, IN2_A>;
+#[doc = "Field `IN2` reader - Write '1' to enable interrupt for event IN\\[2\\]"]
+pub struct IN2_R(crate::FieldReader<bool, IN2_A>);
 impl IN2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN2_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN2_A {
@@ -202,12 +248,19 @@ impl IN2_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN2_A::DISABLED
+        **self == IN2_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN2_A::ENABLED
+        **self == IN2_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN2_R {
+    type Target = crate::FieldReader<bool, IN2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[2\\]\n\nValue on reset: 0"]
@@ -222,7 +275,7 @@ impl From<IN2_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN2`"]
+#[doc = "Field `IN2` writer - Write '1' to enable interrupt for event IN\\[2\\]"]
 pub struct IN2_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +283,7 @@ impl<'a> IN2_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN2_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -252,7 +303,7 @@ impl<'a> IN2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -270,9 +321,13 @@ impl From<IN3_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN3`"]
-pub type IN3_R = crate::R<bool, IN3_A>;
+#[doc = "Field `IN3` reader - Write '1' to enable interrupt for event IN\\[3\\]"]
+pub struct IN3_R(crate::FieldReader<bool, IN3_A>);
 impl IN3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN3_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN3_A {
@@ -284,12 +339,19 @@ impl IN3_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN3_A::DISABLED
+        **self == IN3_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN3_A::ENABLED
+        **self == IN3_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN3_R {
+    type Target = crate::FieldReader<bool, IN3_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[3\\]\n\nValue on reset: 0"]
@@ -304,7 +366,7 @@ impl From<IN3_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN3`"]
+#[doc = "Field `IN3` writer - Write '1' to enable interrupt for event IN\\[3\\]"]
 pub struct IN3_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +374,7 @@ impl<'a> IN3_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN3_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -334,7 +394,7 @@ impl<'a> IN3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -352,9 +412,13 @@ impl From<IN4_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN4`"]
-pub type IN4_R = crate::R<bool, IN4_A>;
+#[doc = "Field `IN4` reader - Write '1' to enable interrupt for event IN\\[4\\]"]
+pub struct IN4_R(crate::FieldReader<bool, IN4_A>);
 impl IN4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN4_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN4_A {
@@ -366,12 +430,19 @@ impl IN4_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN4_A::DISABLED
+        **self == IN4_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN4_A::ENABLED
+        **self == IN4_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN4_R {
+    type Target = crate::FieldReader<bool, IN4_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[4\\]\n\nValue on reset: 0"]
@@ -386,7 +457,7 @@ impl From<IN4_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN4`"]
+#[doc = "Field `IN4` writer - Write '1' to enable interrupt for event IN\\[4\\]"]
 pub struct IN4_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +465,7 @@ impl<'a> IN4_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN4_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -416,7 +485,7 @@ impl<'a> IN4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -434,9 +503,13 @@ impl From<IN5_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN5`"]
-pub type IN5_R = crate::R<bool, IN5_A>;
+#[doc = "Field `IN5` reader - Write '1' to enable interrupt for event IN\\[5\\]"]
+pub struct IN5_R(crate::FieldReader<bool, IN5_A>);
 impl IN5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN5_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN5_A {
@@ -448,12 +521,19 @@ impl IN5_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN5_A::DISABLED
+        **self == IN5_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN5_A::ENABLED
+        **self == IN5_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN5_R {
+    type Target = crate::FieldReader<bool, IN5_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[5\\]\n\nValue on reset: 0"]
@@ -468,7 +548,7 @@ impl From<IN5_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN5`"]
+#[doc = "Field `IN5` writer - Write '1' to enable interrupt for event IN\\[5\\]"]
 pub struct IN5_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +556,7 @@ impl<'a> IN5_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN5_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -498,7 +576,7 @@ impl<'a> IN5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -516,9 +594,13 @@ impl From<IN6_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN6`"]
-pub type IN6_R = crate::R<bool, IN6_A>;
+#[doc = "Field `IN6` reader - Write '1' to enable interrupt for event IN\\[6\\]"]
+pub struct IN6_R(crate::FieldReader<bool, IN6_A>);
 impl IN6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN6_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN6_A {
@@ -530,12 +612,19 @@ impl IN6_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN6_A::DISABLED
+        **self == IN6_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN6_A::ENABLED
+        **self == IN6_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN6_R {
+    type Target = crate::FieldReader<bool, IN6_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[6\\]\n\nValue on reset: 0"]
@@ -550,7 +639,7 @@ impl From<IN6_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN6`"]
+#[doc = "Field `IN6` writer - Write '1' to enable interrupt for event IN\\[6\\]"]
 pub struct IN6_W<'a> {
     w: &'a mut W,
 }
@@ -558,9 +647,7 @@ impl<'a> IN6_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN6_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -580,7 +667,7 @@ impl<'a> IN6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
@@ -598,9 +685,13 @@ impl From<IN7_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN7`"]
-pub type IN7_R = crate::R<bool, IN7_A>;
+#[doc = "Field `IN7` reader - Write '1' to enable interrupt for event IN\\[7\\]"]
+pub struct IN7_R(crate::FieldReader<bool, IN7_A>);
 impl IN7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN7_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN7_A {
@@ -612,12 +703,19 @@ impl IN7_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == IN7_A::DISABLED
+        **self == IN7_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == IN7_A::ENABLED
+        **self == IN7_A::ENABLED
+    }
+}
+impl core::ops::Deref for IN7_R {
+    type Target = crate::FieldReader<bool, IN7_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event IN\\[7\\]\n\nValue on reset: 0"]
@@ -632,7 +730,7 @@ impl From<IN7_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `IN7`"]
+#[doc = "Field `IN7` writer - Write '1' to enable interrupt for event IN\\[7\\]"]
 pub struct IN7_W<'a> {
     w: &'a mut W,
 }
@@ -640,9 +738,7 @@ impl<'a> IN7_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN7_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -662,7 +758,7 @@ impl<'a> IN7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -680,9 +776,13 @@ impl From<PORT_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `PORT`"]
-pub type PORT_R = crate::R<bool, PORT_A>;
+#[doc = "Field `PORT` reader - Write '1' to enable interrupt for event PORT"]
+pub struct PORT_R(crate::FieldReader<bool, PORT_A>);
 impl PORT_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        PORT_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PORT_A {
@@ -694,12 +794,19 @@ impl PORT_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == PORT_A::DISABLED
+        **self == PORT_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == PORT_A::ENABLED
+        **self == PORT_A::ENABLED
+    }
+}
+impl core::ops::Deref for PORT_R {
+    type Target = crate::FieldReader<bool, PORT_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event PORT\n\nValue on reset: 0"]
@@ -714,7 +821,7 @@ impl From<PORT_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `PORT`"]
+#[doc = "Field `PORT` writer - Write '1' to enable interrupt for event PORT"]
 pub struct PORT_W<'a> {
     w: &'a mut W,
 }
@@ -722,9 +829,7 @@ impl<'a> PORT_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PORT_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -744,7 +849,7 @@ impl<'a> PORT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
         self.w
     }
 }
@@ -841,4 +946,30 @@ impl W {
     pub fn port(&mut self) -> PORT_W {
         PORT_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Enable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenset](index.html) module"]
+pub struct INTENSET_SPEC;
+impl crate::RegisterSpec for INTENSET_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenset::R](R) reader structure"]
+impl crate::Readable for INTENSET_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenset::W](W) writer structure"]
+impl crate::Writable for INTENSET_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENSET to value 0"]
+impl crate::Resettable for INTENSET_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
