@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENSET"]
-pub type R = crate::R<u32, super::INTENSET>;
-#[doc = "Writer for register INTENSET"]
-pub type W = crate::W<u32, super::INTENSET>;
-#[doc = "Register INTENSET `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENSET {
-    type Type = u32;
+#[doc = "Register `INTENSET` reader"]
+pub struct R(crate::R<INTENSET_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENSET_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENSET_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENSET_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENSET` writer"]
+pub struct W(crate::W<INTENSET_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENSET_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENSET_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENSET_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to enable interrupt for event TICK\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<TICK_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `TICK`"]
-pub type TICK_R = crate::R<bool, TICK_A>;
+#[doc = "Field `TICK` reader - Write '1' to enable interrupt for event TICK"]
+pub struct TICK_R(crate::FieldReader<bool, TICK_A>);
 impl TICK_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TICK_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TICK_A {
@@ -38,12 +66,19 @@ impl TICK_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == TICK_A::DISABLED
+        **self == TICK_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == TICK_A::ENABLED
+        **self == TICK_A::ENABLED
+    }
+}
+impl core::ops::Deref for TICK_R {
+    type Target = crate::FieldReader<bool, TICK_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event TICK\n\nValue on reset: 0"]
@@ -58,7 +93,7 @@ impl From<TICK_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `TICK`"]
+#[doc = "Field `TICK` writer - Write '1' to enable interrupt for event TICK"]
 pub struct TICK_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +101,7 @@ impl<'a> TICK_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: TICK_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -88,7 +121,7 @@ impl<'a> TICK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -106,9 +139,13 @@ impl From<OVRFLW_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `OVRFLW`"]
-pub type OVRFLW_R = crate::R<bool, OVRFLW_A>;
+#[doc = "Field `OVRFLW` reader - Write '1' to enable interrupt for event OVRFLW"]
+pub struct OVRFLW_R(crate::FieldReader<bool, OVRFLW_A>);
 impl OVRFLW_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVRFLW_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> OVRFLW_A {
@@ -120,12 +157,19 @@ impl OVRFLW_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == OVRFLW_A::DISABLED
+        **self == OVRFLW_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == OVRFLW_A::ENABLED
+        **self == OVRFLW_A::ENABLED
+    }
+}
+impl core::ops::Deref for OVRFLW_R {
+    type Target = crate::FieldReader<bool, OVRFLW_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event OVRFLW\n\nValue on reset: 0"]
@@ -140,7 +184,7 @@ impl From<OVRFLW_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `OVRFLW`"]
+#[doc = "Field `OVRFLW` writer - Write '1' to enable interrupt for event OVRFLW"]
 pub struct OVRFLW_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +192,7 @@ impl<'a> OVRFLW_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: OVRFLW_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -170,7 +212,7 @@ impl<'a> OVRFLW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -188,9 +230,13 @@ impl From<COMPARE0_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE0`"]
-pub type COMPARE0_R = crate::R<bool, COMPARE0_A>;
+#[doc = "Field `COMPARE0` reader - Write '1' to enable interrupt for event COMPARE\\[0\\]"]
+pub struct COMPARE0_R(crate::FieldReader<bool, COMPARE0_A>);
 impl COMPARE0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE0_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE0_A {
@@ -202,12 +248,19 @@ impl COMPARE0_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE0_A::DISABLED
+        **self == COMPARE0_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE0_A::ENABLED
+        **self == COMPARE0_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE0_R {
+    type Target = crate::FieldReader<bool, COMPARE0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event COMPARE\\[0\\]\n\nValue on reset: 0"]
@@ -222,7 +275,7 @@ impl From<COMPARE0_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE0`"]
+#[doc = "Field `COMPARE0` writer - Write '1' to enable interrupt for event COMPARE\\[0\\]"]
 pub struct COMPARE0_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +283,7 @@ impl<'a> COMPARE0_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE0_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -252,7 +303,7 @@ impl<'a> COMPARE0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
@@ -270,9 +321,13 @@ impl From<COMPARE1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE1`"]
-pub type COMPARE1_R = crate::R<bool, COMPARE1_A>;
+#[doc = "Field `COMPARE1` reader - Write '1' to enable interrupt for event COMPARE\\[1\\]"]
+pub struct COMPARE1_R(crate::FieldReader<bool, COMPARE1_A>);
 impl COMPARE1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE1_A {
@@ -284,12 +339,19 @@ impl COMPARE1_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE1_A::DISABLED
+        **self == COMPARE1_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE1_A::ENABLED
+        **self == COMPARE1_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE1_R {
+    type Target = crate::FieldReader<bool, COMPARE1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event COMPARE\\[1\\]\n\nValue on reset: 0"]
@@ -304,7 +366,7 @@ impl From<COMPARE1_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE1`"]
+#[doc = "Field `COMPARE1` writer - Write '1' to enable interrupt for event COMPARE\\[1\\]"]
 pub struct COMPARE1_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +374,7 @@ impl<'a> COMPARE1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE1_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -334,7 +394,7 @@ impl<'a> COMPARE1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
@@ -352,9 +412,13 @@ impl From<COMPARE2_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE2`"]
-pub type COMPARE2_R = crate::R<bool, COMPARE2_A>;
+#[doc = "Field `COMPARE2` reader - Write '1' to enable interrupt for event COMPARE\\[2\\]"]
+pub struct COMPARE2_R(crate::FieldReader<bool, COMPARE2_A>);
 impl COMPARE2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE2_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE2_A {
@@ -366,12 +430,19 @@ impl COMPARE2_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE2_A::DISABLED
+        **self == COMPARE2_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE2_A::ENABLED
+        **self == COMPARE2_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE2_R {
+    type Target = crate::FieldReader<bool, COMPARE2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event COMPARE\\[2\\]\n\nValue on reset: 0"]
@@ -386,7 +457,7 @@ impl From<COMPARE2_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE2`"]
+#[doc = "Field `COMPARE2` writer - Write '1' to enable interrupt for event COMPARE\\[2\\]"]
 pub struct COMPARE2_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +465,7 @@ impl<'a> COMPARE2_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE2_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -416,7 +485,7 @@ impl<'a> COMPARE2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
@@ -434,9 +503,13 @@ impl From<COMPARE3_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE3`"]
-pub type COMPARE3_R = crate::R<bool, COMPARE3_A>;
+#[doc = "Field `COMPARE3` reader - Write '1' to enable interrupt for event COMPARE\\[3\\]"]
+pub struct COMPARE3_R(crate::FieldReader<bool, COMPARE3_A>);
 impl COMPARE3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE3_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE3_A {
@@ -448,12 +521,19 @@ impl COMPARE3_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE3_A::DISABLED
+        **self == COMPARE3_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE3_A::ENABLED
+        **self == COMPARE3_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE3_R {
+    type Target = crate::FieldReader<bool, COMPARE3_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event COMPARE\\[3\\]\n\nValue on reset: 0"]
@@ -468,7 +548,7 @@ impl From<COMPARE3_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE3`"]
+#[doc = "Field `COMPARE3` writer - Write '1' to enable interrupt for event COMPARE\\[3\\]"]
 pub struct COMPARE3_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +556,7 @@ impl<'a> COMPARE3_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE3_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -498,7 +576,7 @@ impl<'a> COMPARE3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
@@ -565,4 +643,30 @@ impl W {
     pub fn compare3(&mut self) -> COMPARE3_W {
         COMPARE3_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Enable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenset](index.html) module"]
+pub struct INTENSET_SPEC;
+impl crate::RegisterSpec for INTENSET_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenset::R](R) reader structure"]
+impl crate::Readable for INTENSET_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenset::W](W) writer structure"]
+impl crate::Writable for INTENSET_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENSET to value 0"]
+impl crate::Resettable for INTENSET_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
