@@ -1,13 +1,37 @@
-#[doc = "Reader of register CONFIG"]
-pub type R = crate::R<u32, super::CONFIG>;
-#[doc = "Writer for register CONFIG"]
-pub type W = crate::W<u32, super::CONFIG>;
-#[doc = "Register CONFIG `reset()`'s with value 0x0002_0000"]
-impl crate::ResetValue for super::CONFIG {
-    type Type = u32;
+#[doc = "Register `CONFIG` reader"]
+pub struct R(crate::R<CONFIG_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<CONFIG_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0x0002_0000
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<CONFIG_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<CONFIG_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `CONFIG` writer"]
+pub struct W(crate::W<CONFIG_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<CONFIG_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<CONFIG_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<CONFIG_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Positive channel resistor control\n\nValue on reset: 0"]
@@ -29,9 +53,13 @@ impl From<RESP_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `RESP`"]
-pub type RESP_R = crate::R<u8, RESP_A>;
+#[doc = "Field `RESP` reader - Positive channel resistor control"]
+pub struct RESP_R(crate::FieldReader<u8, RESP_A>);
 impl RESP_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        RESP_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RESP_A {
@@ -46,25 +74,32 @@ impl RESP_R {
     #[doc = "Checks if the value of the field is `BYPASS`"]
     #[inline(always)]
     pub fn is_bypass(&self) -> bool {
-        *self == RESP_A::BYPASS
+        **self == RESP_A::BYPASS
     }
     #[doc = "Checks if the value of the field is `PULLDOWN`"]
     #[inline(always)]
     pub fn is_pulldown(&self) -> bool {
-        *self == RESP_A::PULLDOWN
+        **self == RESP_A::PULLDOWN
     }
     #[doc = "Checks if the value of the field is `PULLUP`"]
     #[inline(always)]
     pub fn is_pullup(&self) -> bool {
-        *self == RESP_A::PULLUP
+        **self == RESP_A::PULLUP
     }
     #[doc = "Checks if the value of the field is `VDD1_2`"]
     #[inline(always)]
     pub fn is_vdd1_2(&self) -> bool {
-        *self == RESP_A::VDD1_2
+        **self == RESP_A::VDD1_2
     }
 }
-#[doc = "Write proxy for field `RESP`"]
+impl core::ops::Deref for RESP_R {
+    type Target = crate::FieldReader<u8, RESP_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RESP` writer - Positive channel resistor control"]
 pub struct RESP_W<'a> {
     w: &'a mut W,
 }
@@ -72,9 +107,7 @@ impl<'a> RESP_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RESP_A) -> &'a mut W {
-        {
-            self.bits(variant.into())
-        }
+        self.bits(variant.into())
     }
     #[doc = "Bypass resistor ladder"]
     #[inline(always)]
@@ -99,7 +132,7 @@ impl<'a> RESP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | ((value as u32) & 0x03);
+        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
         self.w
     }
 }
@@ -122,9 +155,13 @@ impl From<RESN_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `RESN`"]
-pub type RESN_R = crate::R<u8, RESN_A>;
+#[doc = "Field `RESN` reader - Negative channel resistor control"]
+pub struct RESN_R(crate::FieldReader<u8, RESN_A>);
 impl RESN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        RESN_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RESN_A {
@@ -139,25 +176,32 @@ impl RESN_R {
     #[doc = "Checks if the value of the field is `BYPASS`"]
     #[inline(always)]
     pub fn is_bypass(&self) -> bool {
-        *self == RESN_A::BYPASS
+        **self == RESN_A::BYPASS
     }
     #[doc = "Checks if the value of the field is `PULLDOWN`"]
     #[inline(always)]
     pub fn is_pulldown(&self) -> bool {
-        *self == RESN_A::PULLDOWN
+        **self == RESN_A::PULLDOWN
     }
     #[doc = "Checks if the value of the field is `PULLUP`"]
     #[inline(always)]
     pub fn is_pullup(&self) -> bool {
-        *self == RESN_A::PULLUP
+        **self == RESN_A::PULLUP
     }
     #[doc = "Checks if the value of the field is `VDD1_2`"]
     #[inline(always)]
     pub fn is_vdd1_2(&self) -> bool {
-        *self == RESN_A::VDD1_2
+        **self == RESN_A::VDD1_2
     }
 }
-#[doc = "Write proxy for field `RESN`"]
+impl core::ops::Deref for RESN_R {
+    type Target = crate::FieldReader<u8, RESN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RESN` writer - Negative channel resistor control"]
 pub struct RESN_W<'a> {
     w: &'a mut W,
 }
@@ -165,9 +209,7 @@ impl<'a> RESN_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RESN_A) -> &'a mut W {
-        {
-            self.bits(variant.into())
-        }
+        self.bits(variant.into())
     }
     #[doc = "Bypass resistor ladder"]
     #[inline(always)]
@@ -192,7 +234,7 @@ impl<'a> RESN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | (((value as u32) & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
         self.w
     }
 }
@@ -223,9 +265,13 @@ impl From<GAIN_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `GAIN`"]
-pub type GAIN_R = crate::R<u8, GAIN_A>;
+#[doc = "Field `GAIN` reader - Gain control"]
+pub struct GAIN_R(crate::FieldReader<u8, GAIN_A>);
 impl GAIN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        GAIN_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> GAIN_A {
@@ -244,45 +290,52 @@ impl GAIN_R {
     #[doc = "Checks if the value of the field is `GAIN1_6`"]
     #[inline(always)]
     pub fn is_gain1_6(&self) -> bool {
-        *self == GAIN_A::GAIN1_6
+        **self == GAIN_A::GAIN1_6
     }
     #[doc = "Checks if the value of the field is `GAIN1_5`"]
     #[inline(always)]
     pub fn is_gain1_5(&self) -> bool {
-        *self == GAIN_A::GAIN1_5
+        **self == GAIN_A::GAIN1_5
     }
     #[doc = "Checks if the value of the field is `GAIN1_4`"]
     #[inline(always)]
     pub fn is_gain1_4(&self) -> bool {
-        *self == GAIN_A::GAIN1_4
+        **self == GAIN_A::GAIN1_4
     }
     #[doc = "Checks if the value of the field is `GAIN1_3`"]
     #[inline(always)]
     pub fn is_gain1_3(&self) -> bool {
-        *self == GAIN_A::GAIN1_3
+        **self == GAIN_A::GAIN1_3
     }
     #[doc = "Checks if the value of the field is `GAIN1_2`"]
     #[inline(always)]
     pub fn is_gain1_2(&self) -> bool {
-        *self == GAIN_A::GAIN1_2
+        **self == GAIN_A::GAIN1_2
     }
     #[doc = "Checks if the value of the field is `GAIN1`"]
     #[inline(always)]
     pub fn is_gain1(&self) -> bool {
-        *self == GAIN_A::GAIN1
+        **self == GAIN_A::GAIN1
     }
     #[doc = "Checks if the value of the field is `GAIN2`"]
     #[inline(always)]
     pub fn is_gain2(&self) -> bool {
-        *self == GAIN_A::GAIN2
+        **self == GAIN_A::GAIN2
     }
     #[doc = "Checks if the value of the field is `GAIN4`"]
     #[inline(always)]
     pub fn is_gain4(&self) -> bool {
-        *self == GAIN_A::GAIN4
+        **self == GAIN_A::GAIN4
     }
 }
-#[doc = "Write proxy for field `GAIN`"]
+impl core::ops::Deref for GAIN_R {
+    type Target = crate::FieldReader<u8, GAIN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GAIN` writer - Gain control"]
 pub struct GAIN_W<'a> {
     w: &'a mut W,
 }
@@ -290,9 +343,7 @@ impl<'a> GAIN_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: GAIN_A) -> &'a mut W {
-        {
-            self.bits(variant.into())
-        }
+        self.bits(variant.into())
     }
     #[doc = "1/6"]
     #[inline(always)]
@@ -337,7 +388,7 @@ impl<'a> GAIN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 8)) | (((value as u32) & 0x07) << 8);
+        self.w.bits = (self.w.bits & !(0x07 << 8)) | ((value as u32 & 0x07) << 8);
         self.w
     }
 }
@@ -355,9 +406,13 @@ impl From<REFSEL_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REFSEL`"]
-pub type REFSEL_R = crate::R<bool, REFSEL_A>;
+#[doc = "Field `REFSEL` reader - Reference control"]
+pub struct REFSEL_R(crate::FieldReader<bool, REFSEL_A>);
 impl REFSEL_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        REFSEL_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REFSEL_A {
@@ -369,15 +424,22 @@ impl REFSEL_R {
     #[doc = "Checks if the value of the field is `INTERNAL`"]
     #[inline(always)]
     pub fn is_internal(&self) -> bool {
-        *self == REFSEL_A::INTERNAL
+        **self == REFSEL_A::INTERNAL
     }
     #[doc = "Checks if the value of the field is `VDD1_4`"]
     #[inline(always)]
     pub fn is_vdd1_4(&self) -> bool {
-        *self == REFSEL_A::VDD1_4
+        **self == REFSEL_A::VDD1_4
     }
 }
-#[doc = "Write proxy for field `REFSEL`"]
+impl core::ops::Deref for REFSEL_R {
+    type Target = crate::FieldReader<bool, REFSEL_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REFSEL` writer - Reference control"]
 pub struct REFSEL_W<'a> {
     w: &'a mut W,
 }
@@ -385,9 +447,7 @@ impl<'a> REFSEL_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REFSEL_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Internal reference (0.6 V)"]
     #[inline(always)]
@@ -412,7 +472,7 @@ impl<'a> REFSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
@@ -439,55 +499,65 @@ impl From<TACQ_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `TACQ`"]
-pub type TACQ_R = crate::R<u8, TACQ_A>;
+#[doc = "Field `TACQ` reader - Acquisition time, the time the ADC uses to sample the input voltage"]
+pub struct TACQ_R(crate::FieldReader<u8, TACQ_A>);
 impl TACQ_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        TACQ_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> crate::Variant<u8, TACQ_A> {
-        use crate::Variant::*;
+    pub fn variant(&self) -> Option<TACQ_A> {
         match self.bits {
-            0 => Val(TACQ_A::_3US),
-            1 => Val(TACQ_A::_5US),
-            2 => Val(TACQ_A::_10US),
-            3 => Val(TACQ_A::_15US),
-            4 => Val(TACQ_A::_20US),
-            5 => Val(TACQ_A::_40US),
-            i => Res(i),
+            0 => Some(TACQ_A::_3US),
+            1 => Some(TACQ_A::_5US),
+            2 => Some(TACQ_A::_10US),
+            3 => Some(TACQ_A::_15US),
+            4 => Some(TACQ_A::_20US),
+            5 => Some(TACQ_A::_40US),
+            _ => None,
         }
     }
     #[doc = "Checks if the value of the field is `_3US`"]
     #[inline(always)]
     pub fn is_3us(&self) -> bool {
-        *self == TACQ_A::_3US
+        **self == TACQ_A::_3US
     }
     #[doc = "Checks if the value of the field is `_5US`"]
     #[inline(always)]
     pub fn is_5us(&self) -> bool {
-        *self == TACQ_A::_5US
+        **self == TACQ_A::_5US
     }
     #[doc = "Checks if the value of the field is `_10US`"]
     #[inline(always)]
     pub fn is_10us(&self) -> bool {
-        *self == TACQ_A::_10US
+        **self == TACQ_A::_10US
     }
     #[doc = "Checks if the value of the field is `_15US`"]
     #[inline(always)]
     pub fn is_15us(&self) -> bool {
-        *self == TACQ_A::_15US
+        **self == TACQ_A::_15US
     }
     #[doc = "Checks if the value of the field is `_20US`"]
     #[inline(always)]
     pub fn is_20us(&self) -> bool {
-        *self == TACQ_A::_20US
+        **self == TACQ_A::_20US
     }
     #[doc = "Checks if the value of the field is `_40US`"]
     #[inline(always)]
     pub fn is_40us(&self) -> bool {
-        *self == TACQ_A::_40US
+        **self == TACQ_A::_40US
     }
 }
-#[doc = "Write proxy for field `TACQ`"]
+impl core::ops::Deref for TACQ_R {
+    type Target = crate::FieldReader<u8, TACQ_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TACQ` writer - Acquisition time, the time the ADC uses to sample the input voltage"]
 pub struct TACQ_W<'a> {
     w: &'a mut W,
 }
@@ -530,7 +600,7 @@ impl<'a> TACQ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 16)) | (((value as u32) & 0x07) << 16);
+        self.w.bits = (self.w.bits & !(0x07 << 16)) | ((value as u32 & 0x07) << 16);
         self.w
     }
 }
@@ -548,9 +618,13 @@ impl From<MODE_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `MODE`"]
-pub type MODE_R = crate::R<bool, MODE_A>;
+#[doc = "Field `MODE` reader - Enable differential mode"]
+pub struct MODE_R(crate::FieldReader<bool, MODE_A>);
 impl MODE_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        MODE_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> MODE_A {
@@ -562,15 +636,22 @@ impl MODE_R {
     #[doc = "Checks if the value of the field is `SE`"]
     #[inline(always)]
     pub fn is_se(&self) -> bool {
-        *self == MODE_A::SE
+        **self == MODE_A::SE
     }
     #[doc = "Checks if the value of the field is `DIFF`"]
     #[inline(always)]
     pub fn is_diff(&self) -> bool {
-        *self == MODE_A::DIFF
+        **self == MODE_A::DIFF
     }
 }
-#[doc = "Write proxy for field `MODE`"]
+impl core::ops::Deref for MODE_R {
+    type Target = crate::FieldReader<bool, MODE_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MODE` writer - Enable differential mode"]
 pub struct MODE_W<'a> {
     w: &'a mut W,
 }
@@ -578,9 +659,7 @@ impl<'a> MODE_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: MODE_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Single ended, PSELN will be ignored, negative input to ADC shorted to GND"]
     #[inline(always)]
@@ -605,7 +684,7 @@ impl<'a> MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
@@ -623,9 +702,13 @@ impl From<BURST_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `BURST`"]
-pub type BURST_R = crate::R<bool, BURST_A>;
+#[doc = "Field `BURST` reader - Enable burst mode"]
+pub struct BURST_R(crate::FieldReader<bool, BURST_A>);
 impl BURST_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        BURST_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> BURST_A {
@@ -637,15 +720,22 @@ impl BURST_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == BURST_A::DISABLED
+        **self == BURST_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == BURST_A::ENABLED
+        **self == BURST_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `BURST`"]
+impl core::ops::Deref for BURST_R {
+    type Target = crate::FieldReader<bool, BURST_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `BURST` writer - Enable burst mode"]
 pub struct BURST_W<'a> {
     w: &'a mut W,
 }
@@ -653,9 +743,7 @@ impl<'a> BURST_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: BURST_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Burst mode is disabled (normal operation)"]
     #[inline(always)]
@@ -680,7 +768,7 @@ impl<'a> BURST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
@@ -757,4 +845,30 @@ impl W {
     pub fn burst(&mut self) -> BURST_W {
         BURST_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Description cluster: Input configuration for CH\\[n\\]\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [config](index.html) module"]
+pub struct CONFIG_SPEC;
+impl crate::RegisterSpec for CONFIG_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [config::R](R) reader structure"]
+impl crate::Readable for CONFIG_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [config::W](W) writer structure"]
+impl crate::Writable for CONFIG_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets CONFIG to value 0x0002_0000"]
+impl crate::Resettable for CONFIG_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0x0002_0000
+    }
 }
