@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENCLR"]
-pub type R = crate::R<u32, super::INTENCLR>;
-#[doc = "Writer for register INTENCLR"]
-pub type W = crate::W<u32, super::INTENCLR>;
-#[doc = "Register INTENCLR `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENCLR {
-    type Type = u32;
+#[doc = "Register `INTENCLR` reader"]
+pub struct R(crate::R<INTENCLR_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENCLR_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENCLR_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENCLR_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENCLR` writer"]
+pub struct W(crate::W<INTENCLR_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENCLR_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENCLR_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENCLR_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[0\\]\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<COMPARE0_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE0`"]
-pub type COMPARE0_R = crate::R<bool, COMPARE0_A>;
+#[doc = "Field `COMPARE0` reader - Write '1' to disable interrupt for event COMPARE\\[0\\]"]
+pub struct COMPARE0_R(crate::FieldReader<bool, COMPARE0_A>);
 impl COMPARE0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE0_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE0_A {
@@ -38,12 +66,19 @@ impl COMPARE0_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE0_A::DISABLED
+        **self == COMPARE0_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE0_A::ENABLED
+        **self == COMPARE0_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE0_R {
+    type Target = crate::FieldReader<bool, COMPARE0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[0\\]\n\nValue on reset: 0"]
@@ -58,7 +93,7 @@ impl From<COMPARE0_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE0`"]
+#[doc = "Field `COMPARE0` writer - Write '1' to disable interrupt for event COMPARE\\[0\\]"]
 pub struct COMPARE0_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +101,7 @@ impl<'a> COMPARE0_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE0_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -88,7 +121,7 @@ impl<'a> COMPARE0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
@@ -106,9 +139,13 @@ impl From<COMPARE1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE1`"]
-pub type COMPARE1_R = crate::R<bool, COMPARE1_A>;
+#[doc = "Field `COMPARE1` reader - Write '1' to disable interrupt for event COMPARE\\[1\\]"]
+pub struct COMPARE1_R(crate::FieldReader<bool, COMPARE1_A>);
 impl COMPARE1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE1_A {
@@ -120,12 +157,19 @@ impl COMPARE1_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE1_A::DISABLED
+        **self == COMPARE1_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE1_A::ENABLED
+        **self == COMPARE1_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE1_R {
+    type Target = crate::FieldReader<bool, COMPARE1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[1\\]\n\nValue on reset: 0"]
@@ -140,7 +184,7 @@ impl From<COMPARE1_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE1`"]
+#[doc = "Field `COMPARE1` writer - Write '1' to disable interrupt for event COMPARE\\[1\\]"]
 pub struct COMPARE1_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +192,7 @@ impl<'a> COMPARE1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE1_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -170,7 +212,7 @@ impl<'a> COMPARE1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
@@ -188,9 +230,13 @@ impl From<COMPARE2_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE2`"]
-pub type COMPARE2_R = crate::R<bool, COMPARE2_A>;
+#[doc = "Field `COMPARE2` reader - Write '1' to disable interrupt for event COMPARE\\[2\\]"]
+pub struct COMPARE2_R(crate::FieldReader<bool, COMPARE2_A>);
 impl COMPARE2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE2_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE2_A {
@@ -202,12 +248,19 @@ impl COMPARE2_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE2_A::DISABLED
+        **self == COMPARE2_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE2_A::ENABLED
+        **self == COMPARE2_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE2_R {
+    type Target = crate::FieldReader<bool, COMPARE2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[2\\]\n\nValue on reset: 0"]
@@ -222,7 +275,7 @@ impl From<COMPARE2_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE2`"]
+#[doc = "Field `COMPARE2` writer - Write '1' to disable interrupt for event COMPARE\\[2\\]"]
 pub struct COMPARE2_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +283,7 @@ impl<'a> COMPARE2_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE2_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -252,7 +303,7 @@ impl<'a> COMPARE2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
@@ -270,9 +321,13 @@ impl From<COMPARE3_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE3`"]
-pub type COMPARE3_R = crate::R<bool, COMPARE3_A>;
+#[doc = "Field `COMPARE3` reader - Write '1' to disable interrupt for event COMPARE\\[3\\]"]
+pub struct COMPARE3_R(crate::FieldReader<bool, COMPARE3_A>);
 impl COMPARE3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE3_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE3_A {
@@ -284,12 +339,19 @@ impl COMPARE3_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE3_A::DISABLED
+        **self == COMPARE3_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE3_A::ENABLED
+        **self == COMPARE3_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE3_R {
+    type Target = crate::FieldReader<bool, COMPARE3_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[3\\]\n\nValue on reset: 0"]
@@ -304,7 +366,7 @@ impl From<COMPARE3_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE3`"]
+#[doc = "Field `COMPARE3` writer - Write '1' to disable interrupt for event COMPARE\\[3\\]"]
 pub struct COMPARE3_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +374,7 @@ impl<'a> COMPARE3_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE3_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -334,7 +394,7 @@ impl<'a> COMPARE3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
@@ -352,9 +412,13 @@ impl From<COMPARE4_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE4`"]
-pub type COMPARE4_R = crate::R<bool, COMPARE4_A>;
+#[doc = "Field `COMPARE4` reader - Write '1' to disable interrupt for event COMPARE\\[4\\]"]
+pub struct COMPARE4_R(crate::FieldReader<bool, COMPARE4_A>);
 impl COMPARE4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE4_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE4_A {
@@ -366,12 +430,19 @@ impl COMPARE4_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE4_A::DISABLED
+        **self == COMPARE4_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE4_A::ENABLED
+        **self == COMPARE4_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE4_R {
+    type Target = crate::FieldReader<bool, COMPARE4_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[4\\]\n\nValue on reset: 0"]
@@ -386,7 +457,7 @@ impl From<COMPARE4_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE4`"]
+#[doc = "Field `COMPARE4` writer - Write '1' to disable interrupt for event COMPARE\\[4\\]"]
 pub struct COMPARE4_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +465,7 @@ impl<'a> COMPARE4_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE4_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -416,7 +485,7 @@ impl<'a> COMPARE4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
@@ -434,9 +503,13 @@ impl From<COMPARE5_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `COMPARE5`"]
-pub type COMPARE5_R = crate::R<bool, COMPARE5_A>;
+#[doc = "Field `COMPARE5` reader - Write '1' to disable interrupt for event COMPARE\\[5\\]"]
+pub struct COMPARE5_R(crate::FieldReader<bool, COMPARE5_A>);
 impl COMPARE5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        COMPARE5_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> COMPARE5_A {
@@ -448,12 +521,19 @@ impl COMPARE5_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == COMPARE5_A::DISABLED
+        **self == COMPARE5_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == COMPARE5_A::ENABLED
+        **self == COMPARE5_A::ENABLED
+    }
+}
+impl core::ops::Deref for COMPARE5_R {
+    type Target = crate::FieldReader<bool, COMPARE5_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event COMPARE\\[5\\]\n\nValue on reset: 0"]
@@ -468,7 +548,7 @@ impl From<COMPARE5_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `COMPARE5`"]
+#[doc = "Field `COMPARE5` writer - Write '1' to disable interrupt for event COMPARE\\[5\\]"]
 pub struct COMPARE5_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +556,7 @@ impl<'a> COMPARE5_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: COMPARE5_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -498,7 +576,7 @@ impl<'a> COMPARE5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
@@ -565,4 +643,30 @@ impl W {
     pub fn compare5(&mut self) -> COMPARE5_W {
         COMPARE5_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Disable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenclr](index.html) module"]
+pub struct INTENCLR_SPEC;
+impl crate::RegisterSpec for INTENCLR_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenclr::R](R) reader structure"]
+impl crate::Readable for INTENCLR_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenclr::W](W) writer structure"]
+impl crate::Writable for INTENCLR_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENCLR to value 0"]
+impl crate::Resettable for INTENCLR_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
