@@ -1,13 +1,37 @@
-#[doc = "Reader of register SHORTS"]
-pub type R = crate::R<u32, super::SHORTS>;
-#[doc = "Writer for register SHORTS"]
-pub type W = crate::W<u32, super::SHORTS>;
-#[doc = "Register SHORTS `reset()`'s with value 0"]
-impl crate::ResetValue for super::SHORTS {
-    type Type = u32;
+#[doc = "Register `SHORTS` reader"]
+pub struct R(crate::R<SHORTS_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<SHORTS_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<SHORTS_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<SHORTS_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `SHORTS` writer"]
+pub struct W(crate::W<SHORTS_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<SHORTS_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<SHORTS_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<SHORTS_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Shortcut between event LASTTX and task STARTRX\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<LASTTX_STARTRX_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LASTTX_STARTRX`"]
-pub type LASTTX_STARTRX_R = crate::R<bool, LASTTX_STARTRX_A>;
+#[doc = "Field `LASTTX_STARTRX` reader - Shortcut between event LASTTX and task STARTRX"]
+pub struct LASTTX_STARTRX_R(crate::FieldReader<bool, LASTTX_STARTRX_A>);
 impl LASTTX_STARTRX_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LASTTX_STARTRX_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LASTTX_STARTRX_A {
@@ -38,15 +66,22 @@ impl LASTTX_STARTRX_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LASTTX_STARTRX_A::DISABLED
+        **self == LASTTX_STARTRX_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LASTTX_STARTRX_A::ENABLED
+        **self == LASTTX_STARTRX_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `LASTTX_STARTRX`"]
+impl core::ops::Deref for LASTTX_STARTRX_R {
+    type Target = crate::FieldReader<bool, LASTTX_STARTRX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LASTTX_STARTRX` writer - Shortcut between event LASTTX and task STARTRX"]
 pub struct LASTTX_STARTRX_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +89,7 @@ impl<'a> LASTTX_STARTRX_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LASTTX_STARTRX_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable shortcut"]
     #[inline(always)]
@@ -81,7 +114,7 @@ impl<'a> LASTTX_STARTRX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -99,9 +132,13 @@ impl From<LASTTX_SUSPEND_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LASTTX_SUSPEND`"]
-pub type LASTTX_SUSPEND_R = crate::R<bool, LASTTX_SUSPEND_A>;
+#[doc = "Field `LASTTX_SUSPEND` reader - Shortcut between event LASTTX and task SUSPEND"]
+pub struct LASTTX_SUSPEND_R(crate::FieldReader<bool, LASTTX_SUSPEND_A>);
 impl LASTTX_SUSPEND_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LASTTX_SUSPEND_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LASTTX_SUSPEND_A {
@@ -113,15 +150,22 @@ impl LASTTX_SUSPEND_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LASTTX_SUSPEND_A::DISABLED
+        **self == LASTTX_SUSPEND_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LASTTX_SUSPEND_A::ENABLED
+        **self == LASTTX_SUSPEND_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `LASTTX_SUSPEND`"]
+impl core::ops::Deref for LASTTX_SUSPEND_R {
+    type Target = crate::FieldReader<bool, LASTTX_SUSPEND_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LASTTX_SUSPEND` writer - Shortcut between event LASTTX and task SUSPEND"]
 pub struct LASTTX_SUSPEND_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +173,7 @@ impl<'a> LASTTX_SUSPEND_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LASTTX_SUSPEND_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable shortcut"]
     #[inline(always)]
@@ -156,7 +198,7 @@ impl<'a> LASTTX_SUSPEND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
@@ -174,9 +216,13 @@ impl From<LASTTX_STOP_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LASTTX_STOP`"]
-pub type LASTTX_STOP_R = crate::R<bool, LASTTX_STOP_A>;
+#[doc = "Field `LASTTX_STOP` reader - Shortcut between event LASTTX and task STOP"]
+pub struct LASTTX_STOP_R(crate::FieldReader<bool, LASTTX_STOP_A>);
 impl LASTTX_STOP_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LASTTX_STOP_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LASTTX_STOP_A {
@@ -188,15 +234,22 @@ impl LASTTX_STOP_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LASTTX_STOP_A::DISABLED
+        **self == LASTTX_STOP_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LASTTX_STOP_A::ENABLED
+        **self == LASTTX_STOP_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `LASTTX_STOP`"]
+impl core::ops::Deref for LASTTX_STOP_R {
+    type Target = crate::FieldReader<bool, LASTTX_STOP_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LASTTX_STOP` writer - Shortcut between event LASTTX and task STOP"]
 pub struct LASTTX_STOP_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +257,7 @@ impl<'a> LASTTX_STOP_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LASTTX_STOP_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable shortcut"]
     #[inline(always)]
@@ -231,7 +282,7 @@ impl<'a> LASTTX_STOP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
@@ -249,9 +300,13 @@ impl From<LASTRX_STARTTX_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LASTRX_STARTTX`"]
-pub type LASTRX_STARTTX_R = crate::R<bool, LASTRX_STARTTX_A>;
+#[doc = "Field `LASTRX_STARTTX` reader - Shortcut between event LASTRX and task STARTTX"]
+pub struct LASTRX_STARTTX_R(crate::FieldReader<bool, LASTRX_STARTTX_A>);
 impl LASTRX_STARTTX_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LASTRX_STARTTX_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LASTRX_STARTTX_A {
@@ -263,15 +318,22 @@ impl LASTRX_STARTTX_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LASTRX_STARTTX_A::DISABLED
+        **self == LASTRX_STARTTX_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LASTRX_STARTTX_A::ENABLED
+        **self == LASTRX_STARTTX_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `LASTRX_STARTTX`"]
+impl core::ops::Deref for LASTRX_STARTTX_R {
+    type Target = crate::FieldReader<bool, LASTRX_STARTTX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LASTRX_STARTTX` writer - Shortcut between event LASTRX and task STARTTX"]
 pub struct LASTRX_STARTTX_W<'a> {
     w: &'a mut W,
 }
@@ -279,9 +341,7 @@ impl<'a> LASTRX_STARTTX_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LASTRX_STARTTX_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable shortcut"]
     #[inline(always)]
@@ -306,7 +366,7 @@ impl<'a> LASTRX_STARTTX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
@@ -324,9 +384,13 @@ impl From<LASTRX_SUSPEND_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LASTRX_SUSPEND`"]
-pub type LASTRX_SUSPEND_R = crate::R<bool, LASTRX_SUSPEND_A>;
+#[doc = "Field `LASTRX_SUSPEND` reader - Shortcut between event LASTRX and task SUSPEND"]
+pub struct LASTRX_SUSPEND_R(crate::FieldReader<bool, LASTRX_SUSPEND_A>);
 impl LASTRX_SUSPEND_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LASTRX_SUSPEND_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LASTRX_SUSPEND_A {
@@ -338,15 +402,22 @@ impl LASTRX_SUSPEND_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LASTRX_SUSPEND_A::DISABLED
+        **self == LASTRX_SUSPEND_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LASTRX_SUSPEND_A::ENABLED
+        **self == LASTRX_SUSPEND_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `LASTRX_SUSPEND`"]
+impl core::ops::Deref for LASTRX_SUSPEND_R {
+    type Target = crate::FieldReader<bool, LASTRX_SUSPEND_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LASTRX_SUSPEND` writer - Shortcut between event LASTRX and task SUSPEND"]
 pub struct LASTRX_SUSPEND_W<'a> {
     w: &'a mut W,
 }
@@ -354,9 +425,7 @@ impl<'a> LASTRX_SUSPEND_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LASTRX_SUSPEND_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable shortcut"]
     #[inline(always)]
@@ -381,7 +450,7 @@ impl<'a> LASTRX_SUSPEND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
@@ -399,9 +468,13 @@ impl From<LASTRX_STOP_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LASTRX_STOP`"]
-pub type LASTRX_STOP_R = crate::R<bool, LASTRX_STOP_A>;
+#[doc = "Field `LASTRX_STOP` reader - Shortcut between event LASTRX and task STOP"]
+pub struct LASTRX_STOP_R(crate::FieldReader<bool, LASTRX_STOP_A>);
 impl LASTRX_STOP_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LASTRX_STOP_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LASTRX_STOP_A {
@@ -413,15 +486,22 @@ impl LASTRX_STOP_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LASTRX_STOP_A::DISABLED
+        **self == LASTRX_STOP_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LASTRX_STOP_A::ENABLED
+        **self == LASTRX_STOP_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `LASTRX_STOP`"]
+impl core::ops::Deref for LASTRX_STOP_R {
+    type Target = crate::FieldReader<bool, LASTRX_STOP_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LASTRX_STOP` writer - Shortcut between event LASTRX and task STOP"]
 pub struct LASTRX_STOP_W<'a> {
     w: &'a mut W,
 }
@@ -429,9 +509,7 @@ impl<'a> LASTRX_STOP_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LASTRX_STOP_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable shortcut"]
     #[inline(always)]
@@ -456,7 +534,7 @@ impl<'a> LASTRX_STOP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
@@ -523,4 +601,30 @@ impl W {
     pub fn lastrx_stop(&mut self) -> LASTRX_STOP_W {
         LASTRX_STOP_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Shortcuts between local events and tasks\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [shorts](index.html) module"]
+pub struct SHORTS_SPEC;
+impl crate::RegisterSpec for SHORTS_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [shorts::R](R) reader structure"]
+impl crate::Readable for SHORTS_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [shorts::W](W) writer structure"]
+impl crate::Writable for SHORTS_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets SHORTS to value 0"]
+impl crate::Resettable for SHORTS_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
