@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTEN"]
-pub type R = crate::R<u32, super::INTEN>;
-#[doc = "Writer for register INTEN"]
-pub type W = crate::W<u32, super::INTEN>;
-#[doc = "Register INTEN `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTEN {
-    type Type = u32;
+#[doc = "Register `INTEN` reader"]
+pub struct R(crate::R<INTEN_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTEN_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTEN_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTEN_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTEN` writer"]
+pub struct W(crate::W<INTEN_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTEN_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTEN_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTEN_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Enable or disable interrupt for event CTS\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<CTS_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTS`"]
-pub type CTS_R = crate::R<bool, CTS_A>;
+#[doc = "Field `CTS` reader - Enable or disable interrupt for event CTS"]
+pub struct CTS_R(crate::FieldReader<bool, CTS_A>);
 impl CTS_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CTS_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTS_A {
@@ -38,15 +66,22 @@ impl CTS_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CTS_A::DISABLED
+        **self == CTS_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CTS_A::ENABLED
+        **self == CTS_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `CTS`"]
+impl core::ops::Deref for CTS_R {
+    type Target = crate::FieldReader<bool, CTS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTS` writer - Enable or disable interrupt for event CTS"]
 pub struct CTS_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +89,7 @@ impl<'a> CTS_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTS_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -81,7 +114,7 @@ impl<'a> CTS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -99,9 +132,13 @@ impl From<NCTS_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `NCTS`"]
-pub type NCTS_R = crate::R<bool, NCTS_A>;
+#[doc = "Field `NCTS` reader - Enable or disable interrupt for event NCTS"]
+pub struct NCTS_R(crate::FieldReader<bool, NCTS_A>);
 impl NCTS_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        NCTS_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> NCTS_A {
@@ -113,15 +150,22 @@ impl NCTS_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == NCTS_A::DISABLED
+        **self == NCTS_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == NCTS_A::ENABLED
+        **self == NCTS_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `NCTS`"]
+impl core::ops::Deref for NCTS_R {
+    type Target = crate::FieldReader<bool, NCTS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `NCTS` writer - Enable or disable interrupt for event NCTS"]
 pub struct NCTS_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +173,7 @@ impl<'a> NCTS_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: NCTS_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -156,7 +198,7 @@ impl<'a> NCTS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -174,9 +216,13 @@ impl From<RXDRDY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RXDRDY`"]
-pub type RXDRDY_R = crate::R<bool, RXDRDY_A>;
+#[doc = "Field `RXDRDY` reader - Enable or disable interrupt for event RXDRDY"]
+pub struct RXDRDY_R(crate::FieldReader<bool, RXDRDY_A>);
 impl RXDRDY_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        RXDRDY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RXDRDY_A {
@@ -188,15 +234,22 @@ impl RXDRDY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == RXDRDY_A::DISABLED
+        **self == RXDRDY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == RXDRDY_A::ENABLED
+        **self == RXDRDY_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `RXDRDY`"]
+impl core::ops::Deref for RXDRDY_R {
+    type Target = crate::FieldReader<bool, RXDRDY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RXDRDY` writer - Enable or disable interrupt for event RXDRDY"]
 pub struct RXDRDY_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +257,7 @@ impl<'a> RXDRDY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RXDRDY_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -231,7 +282,7 @@ impl<'a> RXDRDY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -249,9 +300,13 @@ impl From<ENDRX_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `ENDRX`"]
-pub type ENDRX_R = crate::R<bool, ENDRX_A>;
+#[doc = "Field `ENDRX` reader - Enable or disable interrupt for event ENDRX"]
+pub struct ENDRX_R(crate::FieldReader<bool, ENDRX_A>);
 impl ENDRX_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ENDRX_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ENDRX_A {
@@ -263,15 +318,22 @@ impl ENDRX_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == ENDRX_A::DISABLED
+        **self == ENDRX_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == ENDRX_A::ENABLED
+        **self == ENDRX_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `ENDRX`"]
+impl core::ops::Deref for ENDRX_R {
+    type Target = crate::FieldReader<bool, ENDRX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ENDRX` writer - Enable or disable interrupt for event ENDRX"]
 pub struct ENDRX_W<'a> {
     w: &'a mut W,
 }
@@ -279,9 +341,7 @@ impl<'a> ENDRX_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: ENDRX_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -306,7 +366,7 @@ impl<'a> ENDRX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -324,9 +384,13 @@ impl From<TXDRDY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `TXDRDY`"]
-pub type TXDRDY_R = crate::R<bool, TXDRDY_A>;
+#[doc = "Field `TXDRDY` reader - Enable or disable interrupt for event TXDRDY"]
+pub struct TXDRDY_R(crate::FieldReader<bool, TXDRDY_A>);
 impl TXDRDY_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXDRDY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TXDRDY_A {
@@ -338,15 +402,22 @@ impl TXDRDY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == TXDRDY_A::DISABLED
+        **self == TXDRDY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == TXDRDY_A::ENABLED
+        **self == TXDRDY_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `TXDRDY`"]
+impl core::ops::Deref for TXDRDY_R {
+    type Target = crate::FieldReader<bool, TXDRDY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXDRDY` writer - Enable or disable interrupt for event TXDRDY"]
 pub struct TXDRDY_W<'a> {
     w: &'a mut W,
 }
@@ -354,9 +425,7 @@ impl<'a> TXDRDY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: TXDRDY_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -381,7 +450,7 @@ impl<'a> TXDRDY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -399,9 +468,13 @@ impl From<ENDTX_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `ENDTX`"]
-pub type ENDTX_R = crate::R<bool, ENDTX_A>;
+#[doc = "Field `ENDTX` reader - Enable or disable interrupt for event ENDTX"]
+pub struct ENDTX_R(crate::FieldReader<bool, ENDTX_A>);
 impl ENDTX_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ENDTX_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ENDTX_A {
@@ -413,15 +486,22 @@ impl ENDTX_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == ENDTX_A::DISABLED
+        **self == ENDTX_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == ENDTX_A::ENABLED
+        **self == ENDTX_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `ENDTX`"]
+impl core::ops::Deref for ENDTX_R {
+    type Target = crate::FieldReader<bool, ENDTX_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ENDTX` writer - Enable or disable interrupt for event ENDTX"]
 pub struct ENDTX_W<'a> {
     w: &'a mut W,
 }
@@ -429,9 +509,7 @@ impl<'a> ENDTX_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: ENDTX_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -456,7 +534,7 @@ impl<'a> ENDTX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
@@ -474,9 +552,13 @@ impl From<ERROR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `ERROR`"]
-pub type ERROR_R = crate::R<bool, ERROR_A>;
+#[doc = "Field `ERROR` reader - Enable or disable interrupt for event ERROR"]
+pub struct ERROR_R(crate::FieldReader<bool, ERROR_A>);
 impl ERROR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ERROR_A {
@@ -488,15 +570,22 @@ impl ERROR_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == ERROR_A::DISABLED
+        **self == ERROR_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == ERROR_A::ENABLED
+        **self == ERROR_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `ERROR`"]
+impl core::ops::Deref for ERROR_R {
+    type Target = crate::FieldReader<bool, ERROR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ERROR` writer - Enable or disable interrupt for event ERROR"]
 pub struct ERROR_W<'a> {
     w: &'a mut W,
 }
@@ -504,9 +593,7 @@ impl<'a> ERROR_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: ERROR_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -531,7 +618,7 @@ impl<'a> ERROR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
@@ -549,9 +636,13 @@ impl From<RXTO_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RXTO`"]
-pub type RXTO_R = crate::R<bool, RXTO_A>;
+#[doc = "Field `RXTO` reader - Enable or disable interrupt for event RXTO"]
+pub struct RXTO_R(crate::FieldReader<bool, RXTO_A>);
 impl RXTO_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        RXTO_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RXTO_A {
@@ -563,15 +654,22 @@ impl RXTO_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == RXTO_A::DISABLED
+        **self == RXTO_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == RXTO_A::ENABLED
+        **self == RXTO_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `RXTO`"]
+impl core::ops::Deref for RXTO_R {
+    type Target = crate::FieldReader<bool, RXTO_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RXTO` writer - Enable or disable interrupt for event RXTO"]
 pub struct RXTO_W<'a> {
     w: &'a mut W,
 }
@@ -579,9 +677,7 @@ impl<'a> RXTO_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RXTO_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -606,7 +702,7 @@ impl<'a> RXTO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
@@ -624,9 +720,13 @@ impl From<RXSTARTED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RXSTARTED`"]
-pub type RXSTARTED_R = crate::R<bool, RXSTARTED_A>;
+#[doc = "Field `RXSTARTED` reader - Enable or disable interrupt for event RXSTARTED"]
+pub struct RXSTARTED_R(crate::FieldReader<bool, RXSTARTED_A>);
 impl RXSTARTED_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        RXSTARTED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RXSTARTED_A {
@@ -638,15 +738,22 @@ impl RXSTARTED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == RXSTARTED_A::DISABLED
+        **self == RXSTARTED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == RXSTARTED_A::ENABLED
+        **self == RXSTARTED_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `RXSTARTED`"]
+impl core::ops::Deref for RXSTARTED_R {
+    type Target = crate::FieldReader<bool, RXSTARTED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RXSTARTED` writer - Enable or disable interrupt for event RXSTARTED"]
 pub struct RXSTARTED_W<'a> {
     w: &'a mut W,
 }
@@ -654,9 +761,7 @@ impl<'a> RXSTARTED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RXSTARTED_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -681,7 +786,7 @@ impl<'a> RXSTARTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
@@ -699,9 +804,13 @@ impl From<TXSTARTED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `TXSTARTED`"]
-pub type TXSTARTED_R = crate::R<bool, TXSTARTED_A>;
+#[doc = "Field `TXSTARTED` reader - Enable or disable interrupt for event TXSTARTED"]
+pub struct TXSTARTED_R(crate::FieldReader<bool, TXSTARTED_A>);
 impl TXSTARTED_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXSTARTED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TXSTARTED_A {
@@ -713,15 +822,22 @@ impl TXSTARTED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == TXSTARTED_A::DISABLED
+        **self == TXSTARTED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == TXSTARTED_A::ENABLED
+        **self == TXSTARTED_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `TXSTARTED`"]
+impl core::ops::Deref for TXSTARTED_R {
+    type Target = crate::FieldReader<bool, TXSTARTED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXSTARTED` writer - Enable or disable interrupt for event TXSTARTED"]
 pub struct TXSTARTED_W<'a> {
     w: &'a mut W,
 }
@@ -729,9 +845,7 @@ impl<'a> TXSTARTED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: TXSTARTED_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -756,7 +870,7 @@ impl<'a> TXSTARTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
@@ -774,9 +888,13 @@ impl From<TXSTOPPED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `TXSTOPPED`"]
-pub type TXSTOPPED_R = crate::R<bool, TXSTOPPED_A>;
+#[doc = "Field `TXSTOPPED` reader - Enable or disable interrupt for event TXSTOPPED"]
+pub struct TXSTOPPED_R(crate::FieldReader<bool, TXSTOPPED_A>);
 impl TXSTOPPED_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXSTOPPED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TXSTOPPED_A {
@@ -788,15 +906,22 @@ impl TXSTOPPED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == TXSTOPPED_A::DISABLED
+        **self == TXSTOPPED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == TXSTOPPED_A::ENABLED
+        **self == TXSTOPPED_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `TXSTOPPED`"]
+impl core::ops::Deref for TXSTOPPED_R {
+    type Target = crate::FieldReader<bool, TXSTOPPED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXSTOPPED` writer - Enable or disable interrupt for event TXSTOPPED"]
 pub struct TXSTOPPED_W<'a> {
     w: &'a mut W,
 }
@@ -804,9 +929,7 @@ impl<'a> TXSTOPPED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: TXSTOPPED_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -831,7 +954,7 @@ impl<'a> TXSTOPPED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
@@ -948,4 +1071,30 @@ impl W {
     pub fn txstopped(&mut self) -> TXSTOPPED_W {
         TXSTOPPED_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Enable or disable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [inten](index.html) module"]
+pub struct INTEN_SPEC;
+impl crate::RegisterSpec for INTEN_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [inten::R](R) reader structure"]
+impl crate::Readable for INTEN_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [inten::W](W) writer structure"]
+impl crate::Writable for INTEN_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTEN to value 0"]
+impl crate::Resettable for INTEN_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
